@@ -62,6 +62,7 @@ class TestQueue(MoxTestBase):
         queue = Queue(self.store, self.relay)
         queue._add_queued((10, 'one'))
         queue._add_queued((5, 'two'))
+        queue._add_queued((99, 'one'))
         queue._add_queued((7, 'three'))
         self.assertEqual([(5, 'two'), (7, 'three'), (10, 'one')], queue.queued)
         self.assertTrue(queue.wake.isSet())
@@ -202,10 +203,10 @@ class TestQueue(MoxTestBase):
     def test_wait_store(self):
         queue = Queue(self.store, self.relay, relay_pool=5)
         queue.wake = self.mox.CreateMock(AsyncResult)
-        self.store.wait().AndReturn('1234')
+        self.store.wait().AndReturn((1234567890, '1234'))
         queue.wake.set()
         self.store.wait().AndReturn(None)
-        self.store.wait().AndReturn('5678')
+        self.store.wait().AndReturn((2345678901, '5678'))
         queue.wake.set()
         self.store.wait().AndRaise(NotImplementedError)
         self.mox.ReplayAll()
@@ -231,7 +232,7 @@ class TestQueue(MoxTestBase):
         thread = gevent.spawn(wait_func)
         gevent.sleep(0)
         self.assertFalse(thread.ready())
-        queue._add_queued((5, '1234'))
+        queue._add_queued((5, '5678'))
         gevent.sleep(0)
         self.assertTrue(thread.ready())
 
